"""
Run these tests once a patch is deployed to an Antelope server to validate event/ APIs
"""
import requests
from http import HTTPStatus
from xml.etree import ElementTree as ET
from urllib.parse import urlencode
from .util import load_server
from urllib.parse import urljoin
import pytest

WADL_ENDPOINT = 'application.wadl'
VERSION_ENDPOINT = 'version'


def test_version(server):
  api = load_server(server, 'event/')
  _url = urljoin(api, VERSION_ENDPOINT)
  resp = requests.get(_url)
  assert resp.status_code == HTTPStatus.OK

def test_wadl(server):
  api = load_server(server, 'event/')
  _url = urljoin(api, WADL_ENDPOINT)
  resp = requests.get(_url)
  assert resp.status_code == HTTPStatus.OK


ip_op_matrix = [({'mindepth': '0.1', 'maxdepth': 100000, 'minmagnitude': '1', 'maxmagnitude': '10',
                  'orderby': 'time', 'starttime': '2010-01-01 00:00:00', 'minlatitude': '-90', 'maxlatitude': '90',
                  'minlongitude': '-180', 'maxlongitude': '180', 'nodata': '404'},
                 HTTPStatus.OK),
                ({'mindepth': '0.1', 'maxdepth': '100000', 'minmagnitude': '1', 'maxmagnitude': '10',
                  'includeallorigins': 'false', 'orderby': 'time', 'starttime': '2010-01-01 00:00:00', 'minlatitude':
                      '-90', 'maxlatitude': '90', 'minlongitude': '0', 'maxlongitude': '180', 'nodata': '204'},
                 HTTPStatus.NO_CONTENT),
                ({'mindepth': '0.1', 'maxdepth': '1', 'minmagnitude': '1', 'maxmagnitude': '10',
                  'includeallorigins': 'false', 'orderby': 'time', 'starttime': '2010-01-01 00:00:00', 'minlatitude':
                      '-90', 'maxlatitude': '90', 'minlongitude': '0', 'maxlongitude': '180', 'nodata': '404'},
                 HTTPStatus.NOT_FOUND),
                ({'mindepth': 1},
                 HTTPStatus.BAD_REQUEST)]


@pytest.mark.parametrize("query_params, expected_status_code", ip_op_matrix)
def test_event_query_response_codes(server, query_params, expected_status_code):
    api = load_server(server, 'event/')
    query_url = api + 'query?' + urlencode(query_params)
    resp = requests.get(query_url)
    assert(resp.status_code == expected_status_code)


ip_op_matrix_ok = [({'mindepth': '0.1', 'maxdepth': '100000', 'minmagnitude': '1', 'maxmagnitude': '10',
                     'orderby': 'time', 'starttime': '2010-01-01 00:00:00', 'minlatitude': '-90', 'maxlatitude': '90',
                     'minlongitude': '-180', 'maxlongitude': '180', 'nodata': '404'},
                    HTTPStatus.OK),
                   ({'mindepth': '0.1', 'maxdepth': '100000', 'minmagnitude': '1', 'maxmagnitude': '10',
                     'includeallorigins': 'false', 'orderby': 'time', 'starttime': '2010-01-01 00:00:00',
                     'endtime': '2020-01-01 00:00:00', 'minlatitude': '-90', 'maxlatitude': '90', 'minlongitude':
                         '-180', 'maxlongitude': '180', 'nodata': '204'},
                    HTTPStatus.OK),
                   ({'mindepth': '0.1', 'maxdepth': '100000', 'minmagnitude': '1', 'maxmagnitude': '10', 'limit': '2',
                     'includeallorigins': 'false', 'orderby': 'time', 'starttime': '2010-01-01 00:00:00', 'minlatitude':
                         '-90', 'maxlatitude': '90', 'minlongitude': '-180', 'maxlongitude': '180', 'nodata': '404'},
                    HTTPStatus.OK),
                   ({'mindepth': '0.1', 'maxdepth': '100000', 'minmagnitude': '1', 'maxmagnitude': '10', 'limit': '2',
                     'offset': '2', 'includeallorigins': 'false', 'orderby': 'time', 'starttime': '2010-01-01 00:00:00',
                     'minlatitude': '-90', 'maxlatitude': '90', 'minlongitude': '-180', 'maxlongitude': '180',
                     'nodata': '404'},
                    HTTPStatus.OK)]


@pytest.mark.parametrize("query_params, expected_status_code", ip_op_matrix_ok)
def test_event_query_response_content(server, query_params, expected_status_code):
    api = load_server(server, 'event/')
    query_url = api + 'query?' + urlencode(query_params)
    resp = requests.get(query_url)
    assert(resp.status_code == expected_status_code)
    assert('quakeml' in resp.content.decode('utf-8'))
